IF EXISTS (SELECT name FROM master.dbo.sysdatabases WHERE name = N'newmanzone')
	DROP DATABASE [newmanzone]
GO

CREATE DATABASE [newmanzone]
GO

use [newmanzone]
GO

CREATE TABLE [dbo].[DownloadCats] (
	[DownloadCatID] [int] IDENTITY (1, 1) NOT NULL ,
	[DownloadCatName] [varchar] (15) NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[Downloads] (
	[DownloadID] [int] IDENTITY (1, 1) NOT NULL ,
	[DownloadCatID] [int] NOT NULL ,
	[DateAdded] [datetime] NULL ,
	[FileTitle] [varchar] (50) NULL ,
	[Filename] [varchar] (50) NULL ,
	[FilePath] [varchar] (150) NULL ,
	[FileSize] [varchar] (10) NULL ,
	[FileExt] [varchar] (3) NULL ,
	[AuthFirstName] [varchar] (20) NULL ,
	[AuthLastName] [varchar] (30) NULL ,
	[DownloadNo] [varchar] (10) NULL ,
	[Active] [bit] NOT NULL ,
	[Description] [text] NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[Guestbook] (
	[GuestbookID] [int] IDENTITY (1, 1) NOT NULL ,
	[PostDate] [datetime] NOT NULL ,
	[FirstName] [varchar] (50) NULL ,
	[LastName] [varchar] (50) NULL ,
	[City] [varchar] (50) NULL ,
	[State] [varchar] (2) NULL ,
	[Country] [varchar] (50) NOT NULL ,
	[Email] [varchar] (255) NULL ,
	[Website] [varchar] (255) NULL ,
	[Active] [bit] NOT NULL ,
	[Comments] [text] NOT NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[Months] (
	[MonthID] [int] IDENTITY (1, 1) NOT NULL ,
	[MonthName] [varchar] (10) NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[News] (
	[NewsID] [int] IDENTITY (1, 1) NOT NULL ,
	[MonthID] [int] NOT NULL ,
	[NewsDay] [int] NULL ,
	[NewsYear] [int] NULL ,
	[DateAdded] [datetime] NULL ,
	[NewsPic] [varchar] (50) NULL ,
	[PicWidth] [varchar] (3) NULL ,
	[PicHeight] [varchar] (3) NULL ,
	[NewsHeadline] [varchar] (100) NULL ,
	[NewsDesc] [text] NULL 
) ON [PRIMARY]
GO

ALTER TABLE [dbo].[DownloadCats] WITH NOCHECK ADD 
	CONSTRAINT [PK_DownloadCats] PRIMARY KEY  CLUSTERED 
	(
		[DownloadCatID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[Downloads] WITH NOCHECK ADD 
	CONSTRAINT [DF_Downloads_DateAdded] DEFAULT (getdate()) FOR [DateAdded],
	CONSTRAINT [DF_Downloads_DownloadNo] DEFAULT (0) FOR [DownloadNo],
	CONSTRAINT [DF_Downloads_Active] DEFAULT (1) FOR [Active],
	CONSTRAINT [PK_Downloads] PRIMARY KEY  CLUSTERED 
	(
		[DownloadID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[Guestbook] WITH NOCHECK ADD 
	CONSTRAINT [DF_Guestbook_PostDate] DEFAULT (getdate()) FOR [PostDate],
	CONSTRAINT [DF_Guestbook_Active] DEFAULT (1) FOR [Active],
	CONSTRAINT [DF_Guestbook_Comments] DEFAULT (N'1') FOR [Comments],
	CONSTRAINT [PK_Guestbook] PRIMARY KEY  CLUSTERED 
	(
		[GuestbookID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[Months] WITH NOCHECK ADD 
	CONSTRAINT [PK_Months] PRIMARY KEY  CLUSTERED 
	(
		[MonthID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[News] WITH NOCHECK ADD 
	CONSTRAINT [DF_News_DateAdded] DEFAULT (getdate()) FOR [DateAdded],
	CONSTRAINT [PK_News] PRIMARY KEY  CLUSTERED 
	(
		[NewsID]
	)  ON [PRIMARY] 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE VIEW dbo.vwDownloadCats2
AS
SELECT DISTINCT LEFT(DownloadCatName, 3) AS DownloadCatName
FROM         dbo.DownloadCats

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE VIEW dbo.vwDownloadCats
AS
SELECT DISTINCT dbo.DownloadCats.DownloadCatID, dbo.DownloadCats.DownloadCatName, dbo.Downloads.Active
FROM         dbo.DownloadCats INNER JOIN
                      dbo.Downloads ON dbo.DownloadCats.DownloadCatID = dbo.Downloads.DownloadCatID
WHERE     (dbo.Downloads.Active <> 0)

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE spDownloads
@category varchar(15)
AS
SELECT     Downloads.DownloadID, Downloads.DownloadCatID,
DownloadCats.DownloadCatName, Downloads.DateAdded, Downloads.FileTitle,
Downloads.Filename, Downloads.FilePath, Downloads.FileSize,
Downloads.FileExt, Downloads.AuthFirstName + ' ' + Downloads.AuthLastName
AS Author, Downloads.DownloadNo, Downloads.Active, Downloads.Description
FROM       DownloadCats INNER JOIN
Downloads ON DownloadCats.DownloadCatID = Downloads.DownloadCatID
WHERE     (DownloadCats.DownloadCatName LIKE '%' + @category + '%') AND
(Downloads.Active <> 0)
ORDER BY Downloads.FileTitle


GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

--Insert data

--DownloadCats table

INSERT INTO [DownloadCats] ([DownloadCatName])VALUES('ASP')
INSERT INTO [DownloadCats] ([DownloadCatName])VALUES('CF')
INSERT INTO [DownloadCats] ([DownloadCatName])VALUES('JSP')
INSERT INTO [DownloadCats] ([DownloadCatName])VALUES('PHP')
INSERT INTO [DownloadCats] ([DownloadCatName])VALUES('ASP CF')
INSERT INTO [DownloadCats] ([DownloadCatName])VALUES('ASP JSP')
INSERT INTO [DownloadCats] ([DownloadCatName])VALUES('ASP PHP')
INSERT INTO [DownloadCats] ([DownloadCatName])VALUES('CF JSP')
INSERT INTO [DownloadCats] ([DownloadCatName])VALUES('CF PHP')
INSERT INTO [DownloadCats] ([DownloadCatName])VALUES('JSP PHP')
INSERT INTO [DownloadCats] ([DownloadCatName])VALUES('ASP CF JSP')
INSERT INTO [DownloadCats] ([DownloadCatName])VALUES('ASP CF PHP')
INSERT INTO [DownloadCats] ([DownloadCatName])VALUES('ASP JSP PHP')
INSERT INTO [DownloadCats] ([DownloadCatName])VALUES('CF JSP PHP')
INSERT INTO [DownloadCats] ([DownloadCatName])VALUES('ASP CF JSP PHP')


--Downloads table

INSERT INTO [Downloads] ([DownloadCatID],[DateAdded],[FileTitle],[Filename],[FilePath],[FileSize],[FileExt],[AuthFirstName],[AuthLastName],[DownloadNo],[Active],[Description])VALUES(5,'Sep 15 2001 12:00:00:000AM','Conditional Region 2','Conditional_Region.mxp','../../downloads/exts/','85','MXP','Waldo','Smeets','0',1,'With this extension you can show and hide page elements depending on a condition. You can see this as an addition to the Show Region extensions from Macromedia.')
INSERT INTO [Downloads] ([DownloadCatID],[DateAdded],[FileTitle],[Filename],[FilePath],[FileSize],[FileExt],[AuthFirstName],[AuthLastName],[DownloadNo],[Active],[Description])VALUES(1,'Apr 8 2002 12:00:00:000AM','JMail','JMail.mxp','../../downloads/exts/','3','MXP','P.R.','Newman','0',1,'Emails results of submitted form via JMail and stuffs error message (if any) into "strError" variable. Access this object from the ASP tab of the Insert bar.')
INSERT INTO [Downloads] ([DownloadCatID],[DateAdded],[FileTitle],[Filename],[FilePath],[FileSize],[FileExt],[AuthFirstName],[AuthLastName],[DownloadNo],[Active],[Description])VALUES(1,'Sep 17 2001 12:00:00:000AM','Insert Record With Identity','InsertRecordWithId.mxp','../../downloads/exts/','8','MXP','George','Petrov','0',1,'This is a modified Insert Record Server Behaviour. It does everything that the standard Insert Record SB does but adds functionality to return the IDENTITY value of the newly inserted record.')
INSERT INTO [Downloads] ([DownloadCatID],[DateAdded],[FileTitle],[Filename],[FilePath],[FileSize],[FileExt],[AuthFirstName],[AuthLastName],[DownloadNo],[Active],[Description])VALUES(2,'Apr 5 2002 12:00:00:000AM','isDefined','isDefined.mxp','../../downloads/exts/','2','MXP','P.R.','Newman','0',1,'Wraps a CFIF isDefined statement around the selection. Access this object from the CFML Flow tab of the Insert bar.')
INSERT INTO [Downloads] ([DownloadCatID],[DateAdded],[FileTitle],[Filename],[FilePath],[FileSize],[FileExt],[AuthFirstName],[AuthLastName],[DownloadNo],[Active],[Description])VALUES(11,'Sep 12 2001 12:00:00:000AM','Horizontal Looper 2','hlooper2.mxp','../../downloads/exts/','228','MXP','Tom','Muck','0',1,'Similar to a repeat region, this server behavior will loop your records horizontally and vertically. Now works in PHP.')


--Guestbook table

INSERT INTO [Guestbook] ([PostDate],[FirstName],[LastName],[City],[State],[Country],[Email],[Website],[Active],[Comments])VALUES('Nov 24 2001 12:00:00:000AM','Robert','Redford  Redford','Park City','UT','USA','sample@sample.com','http://www.sundance.org/',1,'Oops! Must have gone to the wrong web site.')
INSERT INTO [Guestbook] ([PostDate],[FirstName],[LastName],[City],[State],[Country],[Email],[Website],[Active],[Comments])VALUES('Dec  5 2001 12:00:00:000AM','Joanne','Woodward','New Haven','CT','USA','sample@sample.com','http://us.imdb.com/Name?Woodward,+Joanne',1,'My husband is far better-looking.')
INSERT INTO [Guestbook] ([PostDate],[FirstName],[LastName],[City],[State],[Country],[Email],[Website],[Active],[Comments])VALUES('Dec  7 2001 12:00:00:000AM','George Roy','Hill','Minneapolis','MN','USA','sample@sample.com','http://us.imdb.com/Name?Hill,+George%20Roy',1,'We want to do a sequel - give me a call.')
INSERT INTO [Guestbook] ([PostDate],[FirstName],[LastName],[City],[State],[Country],[Email],[Website],[Active],[Comments])VALUES('Dec  8 2001 12:00:00:000AM','Katharine','Ross','Hollywood','CA','USA','sample@sample.com','http://us.imdb.com/Name?Ross,+Katharine',1,'Did you find my diamond earring? I think it might be under the bed.')
INSERT INTO [Guestbook] ([PostDate],[FirstName],[LastName],[City],[State],[Country],[Email],[Website],[Active],[Comments])VALUES('Dec 11 2001 12:00:00:000AM','William','Goldman','Highland Park','IL','USA','sample@sample.com','http://us.imdb.com/Name?Goldman,+William',1,'I need some help with the script. Call me.')
INSERT INTO [Guestbook] ([PostDate],[FirstName],[LastName],[City],[State],[Country],[Email],[Website],[Active],[Comments])VALUES('Dec 15 2001 12:00:00:000AM','Cloris','Leachman','Des Moines','IA','USA','sample@sample.com','',1,'Excellent rewrite.' + char(10) + char(13) + 'Bill''s a hack.')


--Months table

INSERT INTO [Months] ([MonthName])VALUES('January')
INSERT INTO [Months] ([MonthName])VALUES('February')
INSERT INTO [Months] ([MonthName])VALUES('March')
INSERT INTO [Months] ([MonthName])VALUES('April')
INSERT INTO [Months] ([MonthName])VALUES('May')
INSERT INTO [Months] ([MonthName])VALUES('June')
INSERT INTO [Months] ([MonthName])VALUES('July')
INSERT INTO [Months] ([MonthName])VALUES('August')
INSERT INTO [Months] ([MonthName])VALUES('September')
INSERT INTO [Months] ([MonthName])VALUES('October')
INSERT INTO [Months] ([MonthName])VALUES('November')
INSERT INTO [Months] ([MonthName])VALUES('December')


--News table

INSERT INTO [News] ([MonthID],[NewsDay],[NewsYear],[DateAdded],[NewsPic],[PicWidth],[PicHeight],[NewsHeadline],[NewsDesc])VALUES(10,1,2001,'Oct 1 2001 12:00:00:000AM',NULL,NULL,NULL,'Paul Newman Cast in Butch Cassidy Sequel','In a surprise announcement, 20th Century-Fox has decided to cast newcomer and web designer, Paul Newman, in the role of Butch Cassidy in the upcoming sci-fi/western, "Butch and Sundance in Outer Space."' + char(10) + char(13) + 'Said Joe Mogul, Fox Filmed Entertainment chairman and CEO, "We just feel the name-recognition factor outweighs his obvious lack of experience."' + char(10) + char(13) + 'No word yet on the casting of Sundance Kid, but rumors persist that Brad Pitt will only accept the role if Newman designs his web site.')
INSERT INTO [News] ([MonthID],[NewsDay],[NewsYear],[DateAdded],[NewsPic],[PicWidth],[PicHeight],[NewsHeadline],[NewsDesc])VALUES(1,26,2002,'Jan 26 2002 12:00:00:000AM',NULL,NULL,NULL,'Macromedia to Include Support for ASP.NET in Dreamweaver MX','According to early reports, Dreamweaver MX will offer some support for Microsoft''s new .NET Framework.' + char(10) + char(13) + 'Dreamweaver users will be able to create .NET-compatible web applications using databases such as Microsoft Access and SQL Server, and scripting languages such as C# and VB.NET.' + char(10) + char(13) + 'Web designers fluent in VBScript are advised to learn VB.NET, whereas the C# language will be more familiar to C++ programmers.')
INSERT INTO [News] ([MonthID],[NewsDay],[NewsYear],[DateAdded],[NewsPic],[PicWidth],[PicHeight],[NewsHeadline],[NewsDesc])VALUES(6,10,2002,'Jun 10 2002 12:00:00:000AM',NULL,NULL,NULL,'Macromedia Releases Dreamweaver MX','Today, Macromedia shipped the final release of Dreamweaver MX, the latest version of their highly successful Dreamweaver and UltraDev product lines. ' + char(10) + char(13) + 'The software is now available for download from Macromedia''s web site, in both ESD and evaluation formats. For more information, visit http://www.macromedia.com.')
INSERT INTO [News] ([MonthID],[NewsDay],[NewsYear],[DateAdded],[NewsPic],[PicWidth],[PicHeight],[NewsHeadline],[NewsDesc])VALUES(6,15,2002,'June 15 2002 12:00:00:000AM',NULL,NULL,NULL,'Osborne Publishes <i>The Joy of Dreamweaver MX</i>','Today Osborne/McGraw-Hill, publishers of <i>Dreamweaver MX: The Complete Reference</i>, published <i>The Joy of Dreamweaver MX</i> by P.R. Newman.' + char(10) + char(13) + 'The book consists of 15 "recipes" for data-driven web sites and includes examples in ASP and ColdFusion.' + char(10) + char(13) + 'In addition, the book contains valuable information about new changes in Dreamweaver MX.')


--Done

GO
